#!/usr/bin/env python
#
import os
import os.path
import datetime 
import time

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
__version__ = '0.95'    # Human Readable Version number
version_info = (0,9,5)  # Easier format version data for comparisons
                        # i.e. if version_info > (1,2,5)
                        #
                        #   if __version__ > '1.00' is a little more contrived.
                        
__author__  = 'Benjamin A. Schollnick'
__date__    = '2009-06-03'  # yyyy-mm-dd
__email__   = 'Benjamin@schollnick.net'
__module_name__ = "Time Machine Backup Date Checker"



#
#
#	Configuration Data for Time Capsule / or Airport Extreme / Express Mounted
#	Drives.
#
#	While I have figured out part of the BackupAlias in the com.apple.TimeMachine.plist
#	I have been unable to fully decode the encoded BackupAlias data to allow the plist to
#	serve as the source of that data.
TimeCapsule = True
TimeCapsule_Location = "afp://<server ip or hostname>"
TimeCapsule_Root	 = "/<Name of Share>/"
TimeMachine_Backup_File = "<Name of image file>.sparsebundle"

def	unmount_TimeMachine_Remote_Drive ( mountpoint, imagefile ):
	"""Convience wrapper for the Unmounting of the Remote disk.
	"""
	os.system ('hdiutil detach %s' % imagefile.replace(" ", "\ ") )
	#
	#	The Time.sleep seems to be necessary for the OS to free the mountpoint.
	#	If the sleep is removed the OS always reports that the mountpoint is still busy
	#	and can't be ejected.
	#
	time.sleep (4)
	os.system ('hdiutil detach %s' % mountpoint.replace(" ", "\ ") )

def mount_TimeMachine_Remote_Drive ():
	"""Convience wrapper to mount the time machine remote drive.
	"""
	mount_script = """set timecapsule to "%s"
tell application "Finder"
activate
mount volume timecapsule
end tell""" % TimeCapsule_Location
	os.system ( "osascript -e '%s'" % mount_script)
	#
	#	Used osascript / Applescript since I was having issues with using hdiutil mount.
	#	I was not able to get the mount working via hdiutil.  Any suggestions welcome.
	#
	os.system ( "hdiutil mount /Volumes/%s%s" % (TimeCapsule_Root.replace(" ", "\ "), TimeMachine_Backup_File) )

def	return_TimeMachine_Store_Location ( ):
	""" Run through the mount points in the /Volumes drive, until you find the Backups.backupdb
	directory.  Once you find the first instance, that should be the TimeMachine 'database'.  
	This does not consider systems that may have two different Time Machine stores.

	Returns - 
			Time_Machine_store - which is the full path (eg /Volumes/computer/Backups.backupdb/)
			Time_Machine_Mount_Path - used for the unmounting of the image (if Time Capsule)
									- eg /Volumes/computer
	"""
	Time_Machine_store = ""
	Time_Machine_Mount_Path = ""
	volume_listings = os.listdir("/Volumes")
	for x in volume_listings:
		if os.path.exists ("/Volumes/"+x + "/Backups.backupdb"):
			Time_Machine_Mount_Path = "/Volumes/"+x
			Time_Machine_Root_Path = "/Volumes/"+x + "/Backups.backupdb/"
			Computer_Name = os.listdir ( Time_Machine_Root_Path )[0]
			Time_Machine_store = Time_Machine_Root_Path + Computer_Name
	return Time_Machine_store, Time_Machine_Mount_Path
	
def	return_TimeMachine_Backup_Listings ( store_location):
	"""Returns the directory listing of the Backups.backupdb directory), sorted.
	"""
	Time_Machine_directories = os.listdir ( store_location )
	Time_Machine_directories.sort()
	return Time_Machine_directories

	
if __name__ == '__main__':
	if TimeCapsule:
		mount_TimeMachine_Remote_Drive()
	
	TM_location, TM_mount = return_TimeMachine_Store_Location ()
	
	if TM_location == "" and TM_mount == "":
		message = """osascript -e 'tell app "System Events" to display dialog "Unable to locate your Time Machine Drive." buttons "OK" default button 1 with title "Please Remount your Time Machine Drive..." with icon stop'"""
		os.system (message)
	
	print "Time Machine Store Location - %s" % TM_location
	Time_Machine_directories = return_TimeMachine_Backup_Listings ( TM_location )
	Last_Backup_stamp = time.strptime (Time_Machine_directories[-2], "%Y-%m-%d-%H%M%S")
	Last_Backup_Datetime = datetime.date ( year=Last_Backup_stamp[0], month=Last_Backup_stamp[1], day=Last_Backup_stamp[2] ) 
	now = datetime.date.today()
	day_difference = now - Last_Backup_Datetime
	if day_difference >= datetime.timedelta (5, 0, 0):
		message = """osascript -e 'tell app "System Events" to display dialog "Please Backup your System now.  You have not backed up in more than 5 days." buttons "OK" default button 1 with title "Please Backup Now..." with icon stop'"""
		os.system (message)
	else:
		print "Your backup is less than 5 days old..."
		
	if TimeCapsule:
		unmount_TimeMachine_Remote_Drive ( "/Volumes%s" % TimeCapsule_Root[0:-1],  TM_mount ) 